@@ -281,11 +281,6 @@
 			        $aux_comment = "- NOT Changed ".$aux_changes;
 			    }
 
-			    //FIXME this is only for the 0.7.7->0.7.8 upgrade
-			    if ((count($fields_to_modify)>1) || 
-				((current(array_keys($fields_to_modify))!="mask") &&
-				((current(array_keys($fields_to_modify))!="description") && ($aux_interface_name!="CPU")))
-			    )
 			    if ($log_events==true)
 				insert_event($now_date, $administrative_type_id, $host_id, $aux_interface_name,
 				    "alert","autodiscovery", trim("detected modification $aux_comment"),0); 
