@@ -11,7 +11,7 @@
 	foreach ($var_names as $key=>$name) {
 	    $buffer_name = $name."-".$options["interface_id"];
     
-    	    if (empty($buffer[$buffer_name]) && !empty($values[$key]))  		//if its not already set
+    	    if (empty($buffer[$buffer_name]) && ($values[$key]!==""))  		//if its not already set
     		$buffer[$buffer_name]=$values[$key]; 	//save the data on a buffer, 
     	    						//this has to support satellite session operation
 	}
