@@ -16,7 +16,7 @@ function graph_acct_bytes ($data) {
 
     $opts_header[] = "--vertical-label='Accounting Traffic per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
