@@ -15,6 +15,6 @@ function graph_apps_instances ($data) {
 
     $opts_header[] = "--vertical-label='Number of Threads'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
