@@ -15,7 +15,7 @@
 
 	$opts_header[] = "--vertical-label='Used Memory'"; 
 
-        return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+        return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
     }
 
 ?>
