@@ -27,6 +27,6 @@ function graph_bgp_updates ($data) {
 
     $opts_header[] = "--vertical-label='BGP Updates per 5 Minutes'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
