@@ -27,7 +27,7 @@ function graph_cisco_mac_bytes ($data) {
 
     $opts_header[] = "--vertical-label='Bits per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
