@@ -20,6 +20,6 @@ function graph_cisco_saagent_packetloss ($data) {
 
     $opts_header[] = "--vertical-label='SA Agent % Packet Loss'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
