@@ -15,6 +15,6 @@ function graph_cisco_saagent_rtl ($data) {
 
     $opts_header[] = "--vertical-label='SA Agent Round-Trip Latency'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
