@@ -21,6 +21,6 @@ function graph_cpu_util ($data) {
     $opts_header[] = "--rigid";
     $opts_header[] = "--upper-limit=$limit";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
