@@ -18,6 +18,6 @@ function graph_css_vip_hits ($data) {
 
     $opts_header[] = "--vertical-label='Hits per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
