@@ -19,6 +19,6 @@ function graph_css_vip_output_only_traffic ($data) {
 
     $opts_header[] = "--vertical-label='Bits per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
