@@ -11,7 +11,7 @@ function graph_drop_packets ($data) {
     );
     $opts_header[] = "--vertical-label='Packet Drops per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
