@@ -17,7 +17,7 @@ function graph_error_packets ($data) {
 
     $opts_header[] = "--vertical-label='Errors per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
