@@ -22,7 +22,6 @@ function graph_error_rate ($data) {
 
     $opts_header[] = "--vertical-label='Errors by Packets Rate'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
-
 ?>
