@@ -19,7 +19,6 @@ function graph_hostmib_users_procs ($data) {
 
     $opts_header[] = "--vertical-label='Processes/Users'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
-
 ?>
