@@ -39,6 +39,6 @@ function graph_memory ($data) {
 
     $opts_header[] = "--vertical-label='Used Memory'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
