@@ -14,7 +14,7 @@ function graph_packetloss ($data) {
 
     $opts_header[] = "--vertical-label='Lost Packets'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
