@@ -18,7 +18,7 @@ function graph_packets ($data) {
 
     $opts_header[] = "--vertical-label='Packets per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
