@@ -34,6 +34,6 @@ function graph_packets_aggregation ($data) {
 
     $opts_header[] = "--vertical-label='Packets per Second'";
 
-    return array ($opts_header, array_merge($opts_agg,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_agg,$opts_GRAPH));    
 }
 ?>
