@@ -12,11 +12,11 @@ function graph_rtt ($data) {
         "GPRINT:rtt:LAST:'Last\:%5.0lf msec'"
     );
     
-    if (!empty($data["peer"])) $opts_GRAPH[]="COMMENT:'Peer IP Address: ".$data["$peer"]."'";
+    if (!empty($data["peer"])) $opts_GRAPH[]="COMMENT:'Peer IP Address: ".$data["peer"]."'";
 
     $opts_header[] = "--vertical-label='RTT in Milliseconds'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
