@@ -24,6 +24,6 @@ function graph_tc_rate ($data) {
 
     $opts_header[] = "--vertical-label='Bits per Second'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 ?>
