@@ -41,6 +41,6 @@ function graph_tc_rate_aggregation ($data) {
     
     $opts_header[] = "--vertical-label='Bits per Second'";
 
-    return array ($opts_header, array_merge($defs,$graph));
+    return array ($opts_header, @array_merge($defs,$graph));
 }
 ?>
