@@ -13,7 +13,7 @@ function graph_tcp_conn_number ($data) {
 
     $opts_header[] = "--vertical-label='Established Connections'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
