@@ -1,11 +1,12 @@
 <?
 function graph_tcp_conn_number_aggregation ($data) { 
     $str_cdef = "CDEF:tcp_conn_number=0,";	    	
-
-    foreach ($data[id] as $id) {
+    $opts_agg = array();
+    
+    foreach ($data["id"] as $id) {
 	$interface=$data[$id];
 
-	$opts_agg = array_merge ($opts_agg,rrdtool_get_def($interface,array("number$id"=>"tcp_conn_number")));
+	$opts_agg = @array_merge ($opts_agg,rrdtool_get_def($interface,array("number$id"=>"tcp_conn_number")));
 
 	$str_cdef .="number$id,UN,0,number$id,IF,+,";	    	
     }
@@ -21,7 +22,7 @@ function graph_tcp_conn_number_aggregation ($data) {
 
     $opts_header[] = "--vertical-label='Established Connections'";
 
-    return array ($opts_header, array_merge($opts_agg,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_agg,$opts_GRAPH));    
 }
 
 ?>
