@@ -27,7 +27,7 @@ function graph_tcpmib_connections ($data) {
 
     $opts_header[] = "--vertical-label='TCP Connections Status'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
\ No newline at end of file
