@@ -3,12 +3,9 @@
 
 function graph_temperature ($data) { 
     
-    $opts_DEF = rrdtool_get_def($data,array("temperature"));
+    $opts_DEF = rrdtool_get_def($data,array("temp_c"=>"temperature"));
    
-    if (isset($data["show_celcius"]) && ($data["show_celcius"]==0))
-        $far = 1;
-    else
-        $far = 0;
+    $far = (isset($data["show_celcius"]) && ($data["show_celcius"]==0))?1:0;
 
     $opts_GRAPH = array(
         "CDEF:temperature=temp_c,".(($far==1)?"1.8,*,32,+":"1,*"),
@@ -20,7 +17,7 @@ function graph_temperature ($data) {
 
     $opts_header[] = "--vertical-label='Temperature'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
