@@ -33,7 +33,7 @@ function graph_traffic_pl ($data) {
 
     $opts_header[] = "--vertical-label='% of Lost Packets'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
