@@ -35,7 +35,7 @@ function graph_traffic_util ($data) {
 
     $opts_header[] = "--vertical-label='Utilization %'";
 
-    return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));    
+    return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));    
 }
 
 ?>
