@@ -30,6 +30,6 @@
 
         $opts_header[] = "--vertical-label='Load Average'"; 
          
-        return array ($opts_header, array_merge($opts_DEF,$opts_GRAPH));     
+        return array ($opts_header, @array_merge($opts_DEF,$opts_GRAPH));     
     } 
 ?> 
