@@ -26,15 +26,19 @@
     }
 
     if ($action=="update") {
-	foreach($structure[fields] as $field_name=>$field_data) 
+	foreach($structure["fields"] as $field_name=>$field_data) 
 	    if ($field_name) { 
-		switch ($field_data[type]) { 
+		
+		switch ($field_data["type"]) { 
 		    case "checkbox" : 	if ($$field_name=="") $$field_name=0; break;
-		    case "select"   : 	if (($field_data[params] > 1) && (is_array($$field_name))) { //size > 1 and array result
+		    case "select"   : 	if (($field_data["params"] > 1) && (is_array($$field_name))) { //size > 1 and array result
 					    foreach ($$field_name as $key=>$aux_value) 
-						if ($aux_value > 1)
-	    					    if ($key==0) $api->update($actionid,array($field_name=>$aux_value));
-							else $api->add($filter,$aux_value);
+						if ($aux_value > 1) {
+	    					    if ($key==0)
+							$api->update($actionid,array($field_name=>$aux_value));
+						    else 
+							$api->add($filter,$aux_value);
+						}
 					    $field_name="";
 					}
 					break;
@@ -42,9 +46,8 @@
 		if (($structure[filter_by_user]) && ($field_name==$structure[filter_by_user])) 
 		    $$field_name=$auth_user_id; //filter by user
 
-		if ($field_name) $data[$field_name]=$$field_name;
+		if ($field_name) $data[$field_name]=is_string($$field_name)?trim($$field_name):$$field_name;
 	    }
-	
 	//debug($data);
 	$api->update($actionid,$data);
 	$action="list";
@@ -101,6 +104,7 @@
 
 	    table_shift_color($table_color);
 
+
 	    if (($actionid==$id) && ($action=="edit"))  {
 		adm_form("update");
 		adm_table_row($table_color);
@@ -110,18 +114,26 @@
 
 		if ($structure[show_id]==1) adm_table_cell($id);
 	    
-		foreach ($structure[fields] as $field_name=>$field_data) {
+		foreach ($structure["fields"] as $field_name=>$field_data) {
 		    if ($field_name) {
-			switch ($field_data[type]) {
+			switch ($field_data["type"]) {
 			    case "textbox": adm_table_cell(textbox($field_name,$$field_name,$field_data[size])); break;
 			    case "memobox": adm_table_cell(memobox($field_name,$field_data[height],$field_data[width],$$field_name)); break;
 			    case "checkbox": adm_table_cell(checkbox($field_name,$$field_name,1),"center"); break;
 			    case "select": 
-				    adm_table_cell(call_user_func_array($field_data[func],array_merge(array($field_name,$register[$field_name]),$field_data[params],$register[$field_data[params_field]]))); 
+			    	    if (!is_array($field_data["params"])) $field_data["params"] = array();
+
+				    if (!is_array($register[$field_data["params_field"]])) 
+					$params_field = array($register[$field_data["params_field"]]);
+				    else
+					$params_field = $register[$field_data["params_field"]];
+				    
+				    $aux_param = array_merge(array($field_name,$register[$field_name]),$field_data["params"],$params_field);
+				    adm_table_cell(call_user_func_array($field_data["func"],$aux_param)); 
 				    break;
 		
 			    case "colorbox": adm_table_cell(select_color($field_name,$$field_name,1)); break;
-			    case "hidden" : echo hidden($field_name,$register[$field_name]);
+			    case "hidden" : echo hidden($field_name,$register[$field_name]); break;
 			}
 		    }
 		}
@@ -135,15 +147,31 @@
 	    
 		if ($structure[show_id]==1) adm_table_cell($id);
 
-		foreach ($structure[fields] as $field_name=>$field_data) {
+		foreach ($structure["fields"] as $field_name=>$field_data) {
 		    if ($field_name)
 			switch ($field_data[type]) {
 			    case "textbox": adm_table_cell(htmlspecialchars(substr($$field_name,0,$field_data[size]))); break;
 			    case "memobox": adm_table_cell(htmlspecialchars(substr($$field_name,0,$field_data[size]))); break;
 			    case "checkbox": adm_table_cell(checkbox($field_name,$$field_name,0),"center"); break;
 			    case "select": 
-				if ($field_data[view]) adm_table_cell(htmlspecialchars(substr($$field_data[view],0,$field_data[size]))); 
-				    else adm_table_cell(call_user_func_array($field_data[func],array_merge(array($field_name,$register[$field_name]),$field_data[params],$field_data[view_params],$register[$field_data[params_field]]))); 
+
+			    	if (!is_array($field_data["params"])) $field_data["params"] = array();
+			    	if (!is_array($field_data["view_params"])) $field_data["view_params"] = array();
+			
+				if (!is_array($register[$field_data["params_field"]])) 
+					$params_field = array($register[$field_data["params_field"]]);
+				    else
+					$params_field = $register[$field_data["params_field"]];
+
+				if ($field_data["view"]) 
+				    adm_table_cell(htmlspecialchars(substr($$field_data["view"],0,$field_data["size"]))); 
+				else 
+				    adm_table_cell(call_user_func_array($field_data["func"],
+					array_merge(
+					    array($field_name,$register[$field_name]),
+					    $field_data["params"],
+					    $field_data["view_params"],
+					    $params_field))); 
 				break;
 			    case "colorbox": adm_table_cell(select_color($field_name,$$field_name,0)); break;
 			}
