@@ -5,10 +5,6 @@
 	"show_id"=>1,
 	"profile"=>"ADMIN_HOSTS",
 
-	"action_type"=>2,
-	"split"=>"hosts",
-	"split_view_name"=>"View Hosts",
-	
 	"fields"=>array(
 	    "zone"=>array(	"name"=>"Zone",		"type"=>"textbox",	"size"=>20),
 	    "shortname"=>array(	"name"=>"ShortName",	"type"=>"textbox",	"size"=>20),
@@ -84,7 +80,7 @@
 
 
     $structures["severity"] = array(
-	"title"=>"Severitys",
+	"title"=>"Severities",
 	"object"=>"severity",
 	"show_id"=>0,
 	"action_type"=>1,
@@ -275,7 +271,6 @@
 	"title"=>"SubMaps (Interface Groups)",
 	"object"=>"maps",
 	"show_id"=>1,
-	"hide_record_one"=>1,
 	"action_type"=>2,
 	"split"=>"maps_interfaces",
 	"split_standard"=>1,
