@@ -13,4 +13,7 @@
 
 	//FIXME this has to be more generic
 	if (isset($item["bandwidthin"])) $infobox_text .= "<br>D".($bandwidthin/1000)."k/U".($bandwidthout/1000)."k";
+	
+	if ($item["alarm_name"]!==NULL)
+	    $infobox_text .= "<br><font size=2><b>Alarm:</b> ".$item["alarm_type_description"]." ".ucwords($item["alarm_name"])." since ".$item["alarm_start"]."</font>";
 ?>
