@@ -2,8 +2,8 @@
 
     function interfaces_filter($filters = NULL) {
 	$from = array();
-	$where = NULL;
-	$fields = NULL;
+	$where = array();
+	$fields = array();
 	$index = NULL;
 	$order = NULL;
 	
@@ -109,10 +109,11 @@
 	} else { 
 	    //active alarms for maps
 	    $fields = "SELECT interfaces.id as interface_id, alarm_states.description as alarm, alarm_states.activate_alarm as alarm_level, interfaces.show_rootmap, ".
-	    "alarm_states.id as alarm_id, types.id as type_id, severity.bgcolor, severity.fgcolor";
+	    "alarm_states.id as alarm_id, types.id as type_id, types.description as type, severity.bgcolor, severity.fgcolor, alarms.date_start, alarms.date_stop";
 	    $alarms_filter = "(alarms.date_stop > '$now' /* SLAs */ or alarms.date_stop <= '0001-01-01 00:00:00' /* Not Ended */)"; 
 	    $alarm_state_filter = "alarm_states.state != ".ALARM_UP." /* not UP */";
-	    $group = "GROUP BY interfaces.id, alarms.active, alarms.interface, alarm_states.id, alarm_states.description, alarm_states.activate_alarm, types.id, severity.bgcolor, severity.fgcolor";
+	    $group = "GROUP BY interfaces.id, alarms.active, alarm_states.id, alarm_states.description, alarm_states.activate_alarm, interfaces.show_rootmap, ".
+		"types.id, types.description, severity.bgcolor, severity.fgcolor, alarms.date_start, alarms.date_stop";
 	}
 
 	list ($where_special,$aux_from) = interfaces_filter($filters);
@@ -163,6 +164,7 @@
 	$all_status = array();
 
 	while ($res = db_fetch_array($result)) {
+	    //debug ($res);
 	    if (!$summary) $status = $all_status[$res["interface_id"]];
 
 	    //set total to 0
@@ -176,7 +178,10 @@
 		$status[$res[alarm]][bgcolor]=$res[bgcolor];
 		$status[$res[alarm]][fgcolor]=$res[fgcolor];
 		$status[$res[alarm]][alarm_id]=$res[alarm_id];
-		$status[$res[alarm]][type_id]=$res["type_id"];
+		$status[$res["alarm"]]["type_id"]=$res["type_id"];
+		$status[$res["alarm"]]["type"]=$res["type"];
+		$status[$res["alarm"]]["start"]=$res["date_start"];
+		$status[$res["alarm"]]["stop"]=$res["date_stop"];
 	    }
 
 	    $status[total][qty]++; //increment total anyway
@@ -721,6 +726,7 @@
 	foreach ($filters as $filter_field => $filter_value)
 	    switch ($filter_field) {
 		case "exclude_types" :
+					if (!is_array($filter_value)) $filter_value = array($filter_value);
 					$filter_value=array_merge(array(""),$filter_value);
 					$types_filter .= trim(join(" and ft.id != ",$filter_value));
 					break;
