@@ -52,23 +52,32 @@
 		$start=0;
 		reset ($ret1);
 		while (list ($key,$line) = each ($ret1)) 
-	    	    if ($line!="") {
+	    	    if (!empty($line)) {
+			
 			$line1 = explode(" ",$line);
+			
 			if (strpos($line,":") > 0) {
-			    for ($i = 1; $i < count($line1); $i++) $value[]=(float)$line1[$i];
+
+			    for ($i = 1; $i < count($line1); $i++)			// Part 1 is timestamp
+				if ($line1[$i]!=="") 					// Part 2 maybe is a space
+				    $value[] = ($line1[$i]=="nan")?0:(float)$line1[$i]; // Part 3 (or 2) has the data
 	
-			    $date = (int)$line1[0];
-                            if ( ! isset($stop) ) $stop=0;
+			    $date = (int)$line1[0];					// Time Stamp
+                            if (!isset($stop)) $stop=0;
 			    if ($date > $stop) $stop = $date;
 			    if (($date < $start) or ($start==0)) $start = $date;
 	
 			} else { 
-			    foreach ($line1 as $aux) if ($aux) $ds_namv[]=$aux;
+			    foreach ($line1 as $aux) 
+				if (!empty($aux) && ($aux!="timestamp")) 		// Avoid the timestamp as a DS (rrdtool >= 1.0.49)
+				    $ds_namv[]=trim($aux);
+
 			    $dn_cnt = count($ds_namv);
 			}
 			unset($ret1[$key]);
 		    }
 		    $ret = array("start"=>$start,"end"=>$stop,"step"=>300,"ds_cnt"=>$dn_cnt,"ds_namv"=>$ds_namv,"data"=>$value);
+		    //var_dump($ret);
 	    }
 
 	    $ret2 = 0; //FIXME why update goes bad with satellites
@@ -168,10 +177,10 @@
 		} else logger("ERROR: Calling Function '$real_function' doesn't exists.<br>\n");
 	    } else logger ("ERROR Loading file $function_file.<br>\n");
 
-	    if ($aux=="MINI") { $aux = array_merge($opts_header,array("--no-legend","--alt-y-mrtg")); }
-		else $aux = array_merge($opts_header,$graph_header);
+	    if ($aux=="MINI") { $aux = @array_merge($opts_header,array("--no-legend","--alt-y-mrtg")); }
+		else $aux = @array_merge($opts_header,$graph_header);
 
-	    $opts = array_merge($aux,$graph_definition);
+	    $opts = @array_merge($aux,$graph_definition);
 	    //debug ($opts);
 	    
 	    $graph_filename = get_config_option ("engine_temp_path")."/".uniqid("").".dat"; //generate random graph filename
