@@ -2,7 +2,7 @@
 function select_custom($control_name,$options,$mark_values,$onclick="", $size = 1, $echo = 0, $style = "") {
     
     if ($onclick) 
-	$onclick="onChange='$onclick'";
+	$onclick="onChange=\"$onclick\"";
     
     if ($size > 1) {
 	    $multi = "multiple size='$size'";
@@ -15,7 +15,7 @@ function select_custom($control_name,$options,$mark_values,$onclick="", $size =
     //debug ($options);
     //debug ($mark_values);
     
-    $result .="<select name='$control_name' $onclick $multi $style_class>\n";
+    $result .="<select name='$control_name' id='$control_name'".trim(" $onclick $multi $style_class").">\n";
 
     html_indent_more();
     
@@ -71,7 +71,7 @@ function select_object ($obj_name, $control_name, $selected_values, $add_data =
     foreach ($obj_data as $key=>$value) {
 	unset($aux);
 	foreach ($show_fields as $field_aux) $aux.=$value[$field_aux]. " ";
-	$select_data[$value[$match_field]] = substr($aux,0,32);
+	$select_data[$value[$match_field]] = substr($aux,0,28);
     }
     
     unset($obj_name);
@@ -248,10 +248,12 @@ function checkbox($name,$var,$form = 1) {
     return checkbox_value($name,1,$var,$form);
 }
 
-function checkbox_value($name,$value,$check = 0,$form = 1) {
+function checkbox_value($name,$value,$check = 0,$form = 1, $onclick="") {
     if ($form==0) $name = "checkbox_".rand(1000,9999);
     if ($check==1) $checked=" checked";
-    $result .= "<input type='checkbox' name='$name' value='$value'$checked>\n";
+    if (!empty($onclick)) $js = " onClick=\"$onclick\"";
+    
+    $result .= "<input type='checkbox' name='$name' value='$value'".$checked.$js.">\n";
     return $result;
 }
 
@@ -277,13 +279,14 @@ function adm_form_submit($value = "Submit",$name = NULL) {
     return $result;
 }
 
-function linktext ($text, $url, $target="" ,$style = "", $on_click = "", $echo = 0) {
+function linktext ($text, $url, $target="" ,$style = "", $on_click = "", $echo = 0, $id = "") {
     $result = "<a";
     
     if ($target) $result .= " target='$target'";
     if ($url) 	$result .= " href=\"$url\"";
     if ($style) 	$result .= " style='$style'";
     if ($on_click) 	$result .= " onClick=\"$on_click\"";
+    if ($id) 	$result .= " id=\"$id\"";
 
     $result .= ">";
     
@@ -404,6 +407,10 @@ function popupColor(URL,option) {
 	    $hours[(string)(60*((60*$i)+30))]=str_pad($i,2,"0",STR_PAD_LEFT).":30";
 	}
 	$hours[(60*60*24)]="24:00";
+	
+	if (!empty($actual) && (!isset($hours[$actual]))) 	//if a time is set, but its not round at 30 minutes
+	    $hours[$actual] = substr(time_hms($actual),0,-3);	//add it
+
 	return select_custom($name,$hours,$actual,$onchange);
     }
 
@@ -504,6 +511,7 @@ $trigger_fields = array(
 	"interface"=>		array("name"=>"Interface",	"function"=>"select_interfaces_host",	"params"=>array(6)),
 	"map"=>			array("name"=>"Interface Maps", "function"=>"select_maps",		"params"=>NULL),
 	"interface_client_id"=>	array("name"=>"Client", 	"function"=>"select_clients",		"params"=>array(3)),
+	"interface_interface"=> array("name"=>"Interface Name", "function"=>"textbox",                  "params"=>array(30)), 
 	"none"=>		array("name"=>"None")
     )
 );
@@ -573,7 +581,7 @@ $trigger_fields = array(
 	$list[1]="None Set";
 	$list[]="";
 	$list[]="==== Host Interfaces ====";
-	foreach ($list_int as $key=>$data) $list["I$key"]=$data[interface]." ".substr($data[description],0,30);
+	foreach ($list_int as $key=>$data) $list["I$key"]=$data["interface"]." ".substr($data["description"],0,30);
 	$list[]="";
 	$list[]="==== Maps ====";
 	foreach ($list_map as $key=>$data) $list["M$key"]=$data[name];
@@ -596,7 +604,7 @@ $trigger_fields = array(
 	return $result;
     }
     
-    function interface_value_control ($name, $value, $type) {
+    function interface_value_control ($name, $value, $type = "text") {
 	
 	switch ($type) {
 
@@ -618,7 +626,7 @@ $trigger_fields = array(
     }
     
     function rrdtool_ds_control ($name, $value = "") {
-	
+
 	list ($ds, $ds_name, $ds_type, $hb, $min, $max) = explode (":",$value);
 	
 	if ($max[0]=="<") { //variable
@@ -635,7 +643,7 @@ $trigger_fields = array(
 	$result .= "Type: ".select_custom($name."[type]",$ds_types,$ds_type);
 	$result .= "Min: ".textbox($name."[min]",$min,5);
 
-	if ($auto_max==0) $result .= "Max: ".textbox($name."[max]",$max,5)." or ";
+	if ($auto_max==0) $result .= "Max: ".textbox($name."[max]",$max,10)." or ";
 
 	$result .= "Use ";
 	$result .= textbox ($name."[max_field]",$max_field,5);
@@ -716,5 +724,5 @@ $trigger_fields = array(
 	else 
 	    return $nad_deep_options[$value];
     }
-
+    
 ?>
