@@ -171,20 +171,11 @@
 	foreach ($no_vars as $delete)
 	    unset($REQUEST_URI_VARS[$delete]);
 
-	//$REQUEST_URI_VARS["pepe"]=array("pepe"=>array(1,2,3,3),"lalala","pepep",222333,array(1,2,"lala"=>array(5,"llaa"=>array(1,2,2))));
-	
 	$url_aux=array();
 	clean_url_array($url_aux,"",$REQUEST_URI_VARS);
     
         $REQUEST_URI_CLEAN = $GLOBALS["SCRIPT_NAME"]."?".join("&",$url_aux);
 
-	/*
-        debug($GLOBALS["_GET"]);
-        debug($url_aux);
-	debug($REQUEST_URI_VARS);
-	debug("B: ".$REQUEST_URI_CLEAN);
-	debug("C: ".$GLOBALS["REQUEST_URI"]);
-	*/
 	$GLOBALS["REQUEST_URI"]=$REQUEST_URI_CLEAN; //cleaning up the URL
     }    
 
@@ -387,11 +378,13 @@ function adm_table_td_close() {
 }
 
 function adm_form($action = "",$method="POST",$target = "_self", $echo = 1) {
-    global $SCRIPT_NAME, $id, $init, $filter, $span;
+    global $SCRIPT_NAME, $id, $init, $filter, $span, $actionid;
 
     $result .= html_indenter();
     $result .= "<form action='$SCRIPT_NAME?' method='$method' target='$target'>\n";
 
+    if (!isset($id)) $id = $actionid;
+
     $result .= hidden("actionid",$id);
 
     if ($action) $result .= hidden("action",$action);
@@ -775,7 +768,8 @@ function table_shift_color (&$color) {
 }
 
     //main GET Interfaces manual discovery code
-    function host_interfaces($host_ip,$rocommunity,$hostid) {
+    function host_interfaces($host_ip,$rocommunity,$hostid, $md_type = 0) {
+
 	//JS for Checkboxes
 	echo "<SCRIPT>
 
@@ -811,7 +805,10 @@ function table_shift_color (&$color) {
 	
 	$bulk_add = Array();
 	
-	while ($record = $types_obj->fetch()) if ($record["id"] > 1) { //avoid no interface type
+	while ($record = $types_obj->fetch()) 
+	    if (($record["id"] > 1) && 							//avoid Unknown interface type
+		(($md_type!=2) || (($record["id"]!=2) && ($record["id"]!=23)))) {	// if MDtype=2 No PortScan (TCP/UDP)
+
 	    extract($record);
 	    
 	    unset($db);
@@ -917,16 +914,20 @@ function table_shift_color (&$color) {
 			adm_table_cell (linktext("Edit","adm_interfaces.php?action=edit&interface_id=".$db[$key]["id"]),"center"); //put a edit link
 		    else { //if its not, put an ADD link
 			$bulk_add_id++;
-		
-			foreach ($fields as $fdata) 
-			    if (($fdata["default_value"]!=$value[$fdata["name"]]) && (!empty($value[$fdata["name"]])))
-				$bulk_add[$bulk_add_id][$fdata["name"]]=$value[$fdata["name"]]; //store value for multiple add
-		
-			adm_table_cell (checkbox_value("bulk_add_ids[]",$bulk_add_id,0),"center");
+
+                        foreach ($fields as $fdata)                                                     //for each field
+			    if (($fdata["default_value"]!=$value[$fdata["name"]]) &&                    //is not the default
+				isset($value[$fdata["name"]]) && ($value[$fdata["name"]]!==""))         //if the value is ok
+				    $bulk_add[$bulk_add_id][$fdata["name"]]=$value[$fdata["name"]];     //store value for multiple add
+																		adm_table_cell (checkbox_value("bulk_add_ids[]",$bulk_add_id,0),"center");
 		    }
 		
-	    	    adm_table_cell($value[$index_field],"right");
-		    adm_table_cell($value["interface"]);
+		    if ($value[$index_field]==$value["interface"]) 	//if Index and Inteface name are equal.
+			adm_table_cell($value["interface"],"left",2);	//show only one
+		    else {
+	    		adm_table_cell($value[$index_field],"right");
+			adm_table_cell($value["interface"]);
+		    }
 		    
 		    //Status
 		    unset ($aux);
@@ -1053,7 +1054,7 @@ function table_shift_color (&$color) {
 
 		//Date + Hour
 		"\t<td nowrap bgcolor='$color'>\n".
-		"\t\t<a name='$id' href='$filter_url&express_filter=date,$day_filter'>\n".
+		"\t\t<a name='$id' href='$filter_url&express_filter=date,$day_filter,='>\n".
 		"\t\t$day</a> $hour</td>\n".
 	
 		// Checkbox + Detail		
@@ -1062,27 +1063,27 @@ function table_shift_color (&$color) {
 		"\t\t<a href='$REQUEST_URI&expand=$id&refresh=0&journal_id=0#".($id+1)."'><img src='$image_ack' width='16' height='16'></a></td>\n".
 	
 		// Type
-		"\t<td nowrap ".(($event["show_host"]==0)?" colspan=3":"").(($event["ack"]!=0)?" class='ack'":"").">\n".
-		"\t\t<a style='color: $fgcolor;' href='$filter_url&express_filter=$express_filter^type,".$event["type_id"]."&map_id=$map_id'>\n".
+		"\t<td nowrap ".(($event["show_host"]==0)?" colspan=3":"").(($event["ack"]!=0)?" class='ack'":" class='event'").">\n".
+		"\t\t<a style='color: $fgcolor;' href='$filter_url&express_filter=$express_filter^type,".$event["type_id"].",=&map_id=$map_id'>\n".
 		"\t\t".$event["type_description"]."</a></td>\n";
 	
 		if ($event["show_host"] == 1) //Host + Zone
 		    $output .= 
-		    "\t<td nowrap align='left'".(empty($event["zone_image"])?" colspan=2":"").(($event["ack"]!=0)?" class='ack'":"").">\n".
-		    "\t\t<a style='color: $fgcolor;' href='$filter_url&express_filter=$express_filter^host,".$event["host_id"]."&map_id=$map_id'>\n".
-		    "\t\t&nbsp;".$event["host_name"]." ".$event["zone"]."&nbsp;</a></td>\n".
+		    "\t<td nowrap align='left'".(empty($event["zone_image"])?" colspan=2":"").(($event["ack"]!=0)?" class='ack'":" class='event'").">\n".
+		    "\t\t<a style='color: $fgcolor;' href='$filter_url&express_filter=$express_filter^host,".$event["host_id"].",=&map_id=$map_id'>\n".
+		    "\t\t&nbsp;".substr($event["host_name"],0,20)." ".$event["zone"]."&nbsp;</a></td>\n".
 		    (!empty($event["zone_image"])?
 		    "\t<td nowrap width=1 align='center'>\n".
-		    "\t\t<a style='color: $fgcolor;' href='$filter_url&express_filter=$express_filter^zone,".$event["zone_id"]."&map_id=$map_id'>\n".
+		    "\t\t<a style='color: $fgcolor;' href='$filter_url&express_filter=$express_filter^zone,".$event["zone_id"].",=&map_id=$map_id'>\n".
 		    "\t\t<img src='$jffnms_rel_path/images/".$event["zone_image"]."'></a>":"")."</td>\n";
 	
 		// Event Text
 		$output .= 
-		"\t<td align='left' nowrap style='color: $fgcolor; background-color: $bgcolor;'".(($event["ack"]!=0)?" class='ack'":"").">\n".
+		"\t<td align='left' nowrap style='color: $fgcolor; background-color: $bgcolor;'".(($event["ack"]!=0)?" class='ack'":" class='event'").">\n".
 		"\t\t&nbsp;&nbsp;".$event_text."</td>\n".
 		"</tr>\n";
 
-		if ($expand == $id) {
+		if ($expand == $id) {	//Is this still useful? FIXME change it to a popup or something
 		    $output .= 
 		    "<tr bgcolor='$color'>\n".
 		    "\t<td colspan=2>&nbsp;</td>\n".
@@ -1090,11 +1091,11 @@ function table_shift_color (&$color) {
 	    	    "\t<td colspan=4>\n".
 		    "\t\t<table>\n".
 		    "\t\t\t<tr>\n".
-		    "\t\t\t\t<td nowrap><u>Username:</u> <a href='$filter_url&express_filter=$express_filter^username,".$event["user"]."'>".$event["user"]."</a></td>\n".
-		    "\t\t\t\t<td nowrap><u>Interface:</u> <a href='$filter_url&express_filter=$express_filter^interface,".$event["interface"]."^host,".$event["host_id"]."'>".$event["interface"]."</a></td>\n".
+		    "\t\t\t\t<td nowrap><u>Username:</u> <a href='$filter_url&express_filter=$express_filter^username,".$event["user"].",='>".$event["user"]."</a></td>\n".
+		    "\t\t\t\t<td nowrap><u>Interface:</u> <a href='$filter_url&express_filter=$express_filter^interface,".$event["interface"]."^host,".$event["host_id"].",='>".$event["interface"]."</a></td>\n".
 		    "\t\t\t\t<td nowrap><u>Severity:</u> ".$event["severity"]."</td>\n".
 		    "\t\t\t\t<td nowrap><u>State:</u> ".$event["state"]."</td>\n".
-		    "\t\t\t\t<td nowrap><u>Info:</u> ".$event["$info"]."</td>\n".
+		    "\t\t\t\t<td nowrap><u>Info:</u> ".$event["info"]."</td>\n".
 		    "\t\t\t</tr>\n";
 
 	    	    if ($event["ack"] > 1) {
@@ -1189,7 +1190,7 @@ function table_shift_color (&$color) {
     }
 
     function news_parse () {
-	return array(site=>$GLOBALS["jffnms_site"],version=>$GLOBALS["jffnms_version"],h=>$GLOBALS["info"]["hosts"]["data"],i=>$GLOBALS["info"]["interfaces"]["data"],f=>$_SERVER["REMOTE_ADDR"]);
+	return array("site"=>$GLOBALS["jffnms_site"],"version"=>$GLOBALS["jffnms_version"],"h"=>$GLOBALS["info"]["hosts"]["data"],"i"=>$GLOBALS["info"]["interfaces"]["data"],"f"=>$_SERVER["REMOTE_ADDR"],"php"=>phpversion(),"apache"=>$_SERVER["SERVER_SOFTWARE"]);
     }
 
 ?>
